@@ -1,10 +1,10 @@
-# Build the osarch grain. This grain will be used for platform-specific
-# considerations such as package management. Fall back to the CPU architecture.
 import os
 import shutil
 
 
 async def get_osarch(hub):
+    # Build the osarch grain. This grain will be used for platform-specific
+    # considerations such as package management. Fall back to the CPU architecture.
     if shutil.which("uname"):
         ret = await hub.exec.cmd.run(["uname", "-m"])
         hub.corn.CORN.osarch = ret["stdout"].strip()
@@ -16,13 +16,13 @@ async def get_osarch(hub):
     elif shutil.which("opkg"):
         archinfo = {}
         for line in (
-            await hub.exec.cmd.run(["opkg", "print-architecture"])["stdout"]
+            (await hub.exec.cmd.run(["opkg", "print-architecture"]))["stdout"]
         ).splitlines():
             if line.startswith("arch"):
                 _, arch, priority = line.split()
                 archinfo[arch.strip()] = int(priority.strip())
         # Return osarch in priority order (higher to lower)
-        hub.corn.CORN.osarch = sorted(archinfo, key=archinfo.get, reverse=True)
+        hub.corn.CORN.osarch = sorted(archinfo, key=archinfo.get, reverse=True)[0]
     elif shutil.which("dpkg"):
         hub.corn.CORN.osarch = (await hub.exec.cmd.run("dpkg --print-architecture"))[
             "stdout"
