@@ -113,11 +113,10 @@ _OS_FAMILY_MAP = {
 
 async def _get_synology_osrelease(osrelease: str) -> str:
     # Get os from synology
-    if os.path.isfile("/etc.defaults/VERSION") and os.path.isfile(
-        "/etc.defaults/synoinfo.conf"
-    ):
+    version = "/etc.defaults/VERSION"
+    if os.path.isfile(version) and os.path.isfile("/etc.defaults/synoinfo.conf"):
         log.debug("Parsing Synology distrib info from /etc/.defaults/VERSION")
-        async with aiofiles.open("/etc.defaults/VERSION", "r") as fp_:
+        async with aiofiles.open(version, "r") as fp_:
             synoinfo = {}
             async for line in fp_:
                 try:
@@ -155,34 +154,27 @@ async def _get_os(osfullname: str) -> str:
     return _OS_NAME_MAP.get(shortname, distroname)
 
 
-async def load_build(hub):
-    hub.corn.CORN.osbuild = distro.LinuxDistribution().build_number()
-
-
 async def load_manufacturer(hub):
     # TODO There has got to be a way to programmatically determine this
     # For example, ubuntu is manufactuerd by Canonical, etc...
-    hub.corn.CORN.osmanufactuer = "community"
+    hub.corn.CORN.osmanufactuer = "unknown"
 
 
-async def load_codename(hub):
-    hub.corn.CORN.oscodename = distro.LinuxDistribution().codename().strip("\"'")
-
-
-async def load_majorrelease(hub):
-    hub.corn.CORN.osmajorrelease = int(
-        distro.LinuxDistribution().major_version().strip("\"'")
-    )
-
-
-async def load_os_and_family(hub):
+async def load_linux_distribution(hub):
     info = distro.LinuxDistribution()
+    hub.corn.CORN.osbuild = info.build_number()
+    hub.corn.CORN.oscodename = info.codename().strip("\"'")
+
     hub.corn.CORN.osfullname = info.name().strip("\"'")
     hub.corn.CORN.osrelease = info.version().strip("\"'")
 
-    if not (hub.corn.CORN.osfullname or hub.corn.CORN.osrelease):
+    if not (hub.corn.CORN.get("osfullname") or hub.corn.CORN.get("osrelease")):
         hub.corn.CORN.osrelease = await _get_synology_osrelease(hub.corn.CORN.osrelease)
-        hub.corn.CORN.osfullname = "Synology"
+        if hub.corn.CORN.get("osrelease"):
+            hub.corn.CORN.osfullname = "Synology"
+        else:
+            hub.corn.CORN.osrelease = ""
+            hub.corn.CORN.osfullname = ""
 
     hub.corn.CORN.os = await _get_os(hub.corn.CORN.osfullname)
 
@@ -193,6 +185,11 @@ async def load_os_and_family(hub):
         hub.corn.CORN.ps = "ps -o user,pid,ppid,tty,time,comm"
     hub.corn.CORN.osrelease_info = await _get_osrelease_info(hub.corn.CORN.osrelease)
 
+    major_version = distro.LinuxDistribution().major_version().strip("\"'")
+    hub.corn.CORN.osmajorrelease = (
+        int(major_version) if major_version else hub.corn.CORN.osrelease_info[0]
+    )
+
     # load osfinger
     os_name = hub.corn.CORN[
         "os"
@@ -205,8 +202,5 @@ async def load_os_and_family(hub):
         if os_name in ("Ubuntu",)
         else hub.corn.CORN.osrelease_info[0]
     )
-    hub.corn.CORN.osfinger = f"{os_name}-{finger}"
-
-
-async def load_like(hub):
-    hub.corn.CORN.oslike = distro.like().split(" ")
+    if os_name and finger:
+        hub.corn.CORN.osfinger = f"{os_name}-{finger}"
